┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/tests
diff options
context:
space:
mode:
Diffstat (limited to 'src/tests')
-rw-r--r--src/tests/kitemlistkeyboardsearchmanagertest.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tests/kitemlistkeyboardsearchmanagertest.cpp b/src/tests/kitemlistkeyboardsearchmanagertest.cpp
index be483930d..14a09a31c 100644
--- a/src/tests/kitemlistkeyboardsearchmanagertest.cpp
+++ b/src/tests/kitemlistkeyboardsearchmanagertest.cpp
@@ -75,9 +75,9 @@ void KItemListKeyboardSearchManagerTest::testAbortedKeyboardSearch()
QCOMPARE(spy.count(), 1);
QCOMPARE(spy.takeFirst(), QList<QVariant>() << "fi" << false);
// If the delay between two key presses is larger than QApplication::keyboardInputInterval(),
// a new search is started. We add a small safety margin to avoid race conditions.
- QTest::qWait(QApplication::keyboardInputInterval() + 10);
+ QTest::qWait(5000 + 10);
m_keyboardSearchManager.addKeys("l");
QCOMPARE(spy.count(), 1);
@@ -75,9 +75,9 @@ void KItemListKeyboardSearchManagerTest::testAbortedKeyboardSearch()
QCOMPARE(spy.count(), 1);
QCOMPARE(spy.takeFirst(), QList<QVariant>() << "fi" << false);
- // If the delay between two key presses is larger than QApplication::keyboardInputInterval(),
+ // If the delay between two key presses is larger than 5000 milliseconds,
// a new search is started. We add a small safety margin to avoid race conditions.